@@ -1,5 +1,7 @@
 """
-Main interface for mgn service literal definitions.
+Type annotations for mgn service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/literals.html)
 
 Usage::
 
