@@ -1,5 +1,7 @@
 """
-Main interface for mgn service client paginators.
+Type annotations for mgn service client paginators.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html)
 
 Usage::
 
@@ -46,20 +48,21 @@ __all__ = (
 
 class DescribeJobLogItemsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeJobLogItems documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/mgn.html#mgn.Paginator.DescribeJobLogItems)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/mgn.html#mgn.Paginator.DescribeJobLogItems)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejoblogitemspaginator)
     """
 
     def paginate(
         self, jobID: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeJobLogItemsResponseTypeDef]:
         """
-        [DescribeJobLogItems.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/mgn.html#mgn.Paginator.DescribeJobLogItems.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/mgn.html#mgn.Paginator.DescribeJobLogItems.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejoblogitemspaginator)
         """
 
 
 class DescribeJobsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/mgn.html#mgn.Paginator.DescribeJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/mgn.html#mgn.Paginator.DescribeJobs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejobspaginator)
     """
 
     def paginate(
@@ -68,13 +71,14 @@ class DescribeJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeJobsResponseTypeDef]:
         """
-        [DescribeJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/mgn.html#mgn.Paginator.DescribeJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/mgn.html#mgn.Paginator.DescribeJobs.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejobspaginator)
         """
 
 
 class DescribeReplicationConfigurationTemplatesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReplicationConfigurationTemplates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/mgn.html#mgn.Paginator.DescribeReplicationConfigurationTemplates)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/mgn.html#mgn.Paginator.DescribeReplicationConfigurationTemplates)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describereplicationconfigurationtemplatespaginator)
     """
 
     def paginate(
@@ -83,13 +87,14 @@ class DescribeReplicationConfigurationTemplatesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeReplicationConfigurationTemplatesResponseTypeDef]:
         """
-        [DescribeReplicationConfigurationTemplates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/mgn.html#mgn.Paginator.DescribeReplicationConfigurationTemplates.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/mgn.html#mgn.Paginator.DescribeReplicationConfigurationTemplates.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describereplicationconfigurationtemplatespaginator)
         """
 
 
 class DescribeSourceServersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeSourceServers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/mgn.html#mgn.Paginator.DescribeSourceServers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/mgn.html#mgn.Paginator.DescribeSourceServers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describesourceserverspaginator)
     """
 
     def paginate(
@@ -98,5 +103,6 @@ class DescribeSourceServersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeSourceServersResponseTypeDef]:
         """
-        [DescribeSourceServers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/mgn.html#mgn.Paginator.DescribeSourceServers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/mgn.html#mgn.Paginator.DescribeSourceServers.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describesourceserverspaginator)
         """
